@@ -12,6 +12,7 @@ import (
 
 	"github.com/superfly/flyctl/internal/command"
 	"github.com/superfly/flyctl/internal/config"
+	"github.com/superfly/flyctl/internal/flag"
 	"github.com/superfly/flyctl/internal/render"
 )
 
@@ -25,6 +26,7 @@ func newPing() (cmd *cobra.Command) {
 
 	cmd.Args = cobra.NoArgs
 
+	flag.Add(cmd, flag.JSONOutput())
 	return
 }
 
