@@ -11,14 +11,11 @@ import (
 	"github.com/superfly/flyctl/iostreams"
 
 	"github.com/superfly/flyctl/internal/buildinfo"
-	"github.com/superfly/flyctl/internal/cache"
 	"github.com/superfly/flyctl/internal/command"
 	"github.com/superfly/flyctl/internal/config"
 	"github.com/superfly/flyctl/internal/flag"
 )
 
-const saveInstallName = "saveinstall"
-
 // New initializes and returns a new version Command.
 func New() *cobra.Command {
 	const (
@@ -33,14 +30,15 @@ number and build date.`
 	// TODO: remove once installer is updated to use init-state
 	flag.Add(version,
 		flag.String{
-			Name:        saveInstallName,
+			Name:        "saveinstall",
 			Shorthand:   "s",
 			Description: "Save parameter in config",
+			Hidden:      true,
 		},
 	)
 
 	version.AddCommand(
-		newInitState(),
+		newSaveInstall(),
 		newUpgrade(),
 	)
 
@@ -49,14 +47,8 @@ number and build date.`
 }
 
 func run(ctx context.Context) (err error) {
-	if saveInstall := flag.GetString(ctx, saveInstallName); saveInstall != "" {
-		err = executeInitState(
-			iostreams.FromContext(ctx),
-			cache.FromContext(ctx),
-			saveInstall,
-		)
-
-		return
+	if channel := flag.GetString(ctx, "saveinstall"); channel != "" {
+		return saveInstall(ctx, channel, true)
 	}
 
 	var (
